############
Known Issues
############

* Currently, the code is not aware of ``retool``'s supersets or compilations array.

* Occasionally, multiple ROMs will be found with the same priority.

  * This will be improved with more regex flags in future releases
